@@ -5,7 +5,7 @@ use warnings;
 
 use parent qw(IO::Async::Notifier);
 
-our $VERSION = '0.023';
+our $VERSION = '0.024';
 
 =head1 NAME
 
@@ -13,7 +13,7 @@ Net::Async::AMQP - provides client interface to AMQP using L<IO::Async>
 
 =head1 VERSION
 
-version 0.023
+version 0.024
 
 =head1 SYNOPSIS
 
@@ -671,11 +671,13 @@ sub close {
 	# We might end up with a connection shutdown rather
 	# than a clean Connection::Close response, so
 	# we need to handle both possibilities
+	my @handler;
 	$self->bus->subscribe_to_event(
-		my @handler = (
+		@handler = (
 			close => sub {
 				my ($ev, $reason) = @_;
-				$ev->unsubscribe;
+				splice @handler;
+				eval { $ev->unsubscribe; };
 				return unless $f;
 				$f->done($reason) unless $f->is_ready;
 				weaken $f;
