@@ -1,5 +1,5 @@
 package Net::Async::AMQP::Channel;
-$Net::Async::AMQP::Channel::VERSION = '0.023';
+$Net::Async::AMQP::Channel::VERSION = '0.024';
 use strict;
 use warnings;
 
@@ -11,7 +11,7 @@ Net::Async::AMQP::Channel - represents a single channel in an MQ connection
 
 =head1 VERSION
 
-version 0.023
+version 0.024
 
 =head1 SYNOPSIS
 
@@ -714,8 +714,8 @@ sub closure_protection {
 			unless($f) {
 				$self->debug_printf("Future has disappeared already, not marking as failed");
 				# We should have unsubscribed already, but do this just in case.
-				$ev->unsubscribe;
 				splice @ev;
+				eval { $ev->unsubscribe; };
 				return;
 			}
 
