@@ -1,5 +1,5 @@
 package Net::Async::AMQP::ConnectionManager;
-$Net::Async::AMQP::ConnectionManager::VERSION = '0.023';
+$Net::Async::AMQP::ConnectionManager::VERSION = '0.024';
 use strict;
 use warnings;
 
@@ -11,7 +11,7 @@ Net::Async::AMQP::ConnectionManager - handle MQ connections
 
 =head1 VERSION
 
-version 0.023
+version 0.024
 
 =head1 SYNOPSIS
 
@@ -363,7 +363,8 @@ sub request_connection {
 				$mq->bus->subscribe_to_event(
 					close => sub {
 						# Drop this connection on close.
-						shift->unsubscribe;
+						my ($ev) = @_;
+						eval { $ev->unsubscribe; };
 						Scalar::UtilsBy::extract_by {
 							Scalar::Util::refaddr($_) eq Scalar::Util::refaddr($mq)
 						} @{$self->{available_connections}};
@@ -469,7 +470,7 @@ sub on_channel_close {
 	my ($self, $ch, $ev, %args) = @_;
 	$self->debug_printf("channel closure: %s", join ' ', @_);
 	# Channel closure only happens once per channel
-	$ev->unsubscribe;
+	eval { $ev->unsubscribe; };
 
 	$self->debug_printf("Adding closed channel %d back to the available list", $ch->id);
 	my $amqp = $ch->amqp or die "This channel (" . $ch->id . ") has no AMQP connection";
