@@ -1,5 +1,5 @@
 package Net::Async::AMQP::ConnectionManager::Channel;
-$Net::Async::AMQP::ConnectionManager::Channel::VERSION = '0.023';
+$Net::Async::AMQP::ConnectionManager::Channel::VERSION = '0.024';
 use strict;
 use warnings;
 
@@ -9,7 +9,7 @@ Net::Async::AMQP::ConnectionManager::Channel - channel proxy object
 
 =head1 VERSION
 
-version 0.023
+version 0.024
 
 =cut
 
@@ -73,7 +73,7 @@ sub _listener_start {
 		Net::Async::AMQP::Queue->new(
 			amqp    => $self->amqp,
 			channel => $self,
-			future  => Future->wrap
+			future  => Future->done()
 		)->cancel(
 			consumer_tag => $ctag
 		)
